# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1906
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_analytic_model.models.dataservices_datamodel_parameter_definition_dto import DataservicesDatamodelParameterDefinitionDTO
from visier_api_analytic_model.models.dataservices_datamodel_tag_map_element_dto import DataservicesDatamodelTagMapElementDTO
from typing import Optional, Set
from typing_extensions import Self

class DataservicesDatamodelPropertyDTO(BaseModel):
    """
    Properties are qualities of an analytic object.
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="The unique ID of the property.  **Note:** See `Properties` to get the ID.")
    display_name: Optional[StrictStr] = Field(default=None, description="The localized display name of the property.", alias="displayName")
    description: Optional[StrictStr] = Field(default=None, description="The localized description of the property.")
    data_type: Optional[StrictStr] = Field(default=None, description="The data type of the property, such as Categorical, HourDuration, or Ratio.", alias="dataType")
    primitive_data_type: Optional[StrictStr] = Field(default=None, description="The primitive data type of the property, such as Number, String, or Boolean.", alias="primitiveDataType")
    parameters: Optional[List[DataservicesDatamodelParameterDefinitionDTO]] = Field(default=None, description="The collection of parameters defined for the property.")
    tags: Optional[List[DataservicesDatamodelTagMapElementDTO]] = Field(default=None, description="The optional collection of tags defined for this element.")
    explanation: Optional[StrictStr] = Field(default=None, description="The localized explanation of the property.")
    __properties: ClassVar[List[str]] = ["id", "displayName", "description", "dataType", "primitiveDataType", "parameters", "tags", "explanation"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DataservicesDatamodelPropertyDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in parameters (list)
        _items = []
        if self.parameters:
            for _item_parameters in self.parameters:
                if _item_parameters:
                    _items.append(_item_parameters.to_dict())
            _dict['parameters'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DataservicesDatamodelPropertyDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "displayName": obj.get("displayName"),
            "description": obj.get("description"),
            "dataType": obj.get("dataType"),
            "primitiveDataType": obj.get("primitiveDataType"),
            "parameters": [DataservicesDatamodelParameterDefinitionDTO.from_dict(_item) for _item in obj["parameters"]] if obj.get("parameters") is not None else None,
            "tags": [DataservicesDatamodelTagMapElementDTO.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "explanation": obj.get("explanation")
        })
        return _obj





# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1906
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

import visier_api_analytic_model.models
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_concept_delete_request_dto import ServicingV2ObjectconfigurationConceptDeleteRequestDTO

class TestServicingV2ObjectconfigurationConceptDeleteRequestDTO(unittest.TestCase):
    """ServicingV2ObjectconfigurationConceptDeleteRequestDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServicingV2ObjectconfigurationConceptDeleteRequestDTO:
        """Test ServicingV2ObjectconfigurationConceptDeleteRequestDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """

        if include_optional:
            return ServicingV2ObjectconfigurationConceptDeleteRequestDTO(
                concepts = [
                    visier_api_analytic_model.models.servicing/v2/objectconfiguration/concept_delete_with_context_dto.servicing.v2.objectconfiguration.ConceptDeleteWithContextDTO(
                        execution_context = None, 
                        concept = None, )
                    ]
            )
        else:
            return ServicingV2ObjectconfigurationConceptDeleteRequestDTO(
        )

    def testServicingV2ObjectconfigurationConceptDeleteRequestDTO(self):
        """Test ServicingV2ObjectconfigurationConceptDeleteRequestDTO"""
        def validate_instance(instance):
            ServicingV2ObjectconfigurationConceptDeleteRequestDTO.model_validate(inst_req_only)
            instance_deserialized = ServicingV2ObjectconfigurationConceptDeleteRequestDTO.from_dict(instance.to_dict())
            assert instance == instance_deserialized

        inst_req_only = self.make_instance(include_optional=False)
        validate_instance(inst_req_only)

        inst_req_and_optional = self.make_instance(include_optional=True)
        validate_instance(inst_req_and_optional)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1906
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from visier_api_core import ApiClient, ApiResponse, RequestSerialized, RESTResponseType

from pydantic import Field, StrictStr
from typing import Optional
from typing_extensions import Annotated
from visier_api_analytic_model.models.designer_api_calculation_concept_configuration_map_dto import DesignerApiCalculationConceptConfigurationMapDTO
from visier_api_analytic_model.models.designer_api_calculation_concept_dto import DesignerApiCalculationConceptDTO
from visier_api_analytic_model.models.designer_api_calculation_concept_list_dto import DesignerApiCalculationConceptListDTO
from visier_api_analytic_model.models.designer_api_concept_configuration_result_dto import DesignerApiConceptConfigurationResultDTO
from visier_api_analytic_model.models.designer_api_selection_concept_configuration_map_dto import DesignerApiSelectionConceptConfigurationMapDTO
from visier_api_analytic_model.models.designer_api_selection_concept_dto import DesignerApiSelectionConceptDTO
from visier_api_analytic_model.models.designer_api_selection_concept_list_dto import DesignerApiSelectionConceptListDTO
import visier_api_analytic_model.models


class ObjectConfigurationApi:
    """
    This class provides methods to make requests to the Visier API.
    It uses the ApiClient to handle the HTTP requests and responses.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_calculation_concept(
        self,
        concept_id: Annotated[StrictStr, Field(description="The ID of the concept to retrieve the configuration for.")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DesignerApiCalculationConceptDTO:
        """Retrieve the configuration of a calculation concept

        Retrieve the configuration details of a calculation concept in production.

        :param concept_id: The ID of the concept to retrieve the configuration for. (required)
        :type concept_id: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_calculation_concept_serialize(
            concept_id=concept_id,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiCalculationConceptDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_analytic_model.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def get_calculation_concept_with_http_info(
        self,
        concept_id: Annotated[StrictStr, Field(description="The ID of the concept to retrieve the configuration for.")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DesignerApiCalculationConceptDTO]:
        """Retrieve the configuration of a calculation concept

        Retrieve the configuration details of a calculation concept in production.

        :param concept_id: The ID of the concept to retrieve the configuration for. (required)
        :type concept_id: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_calculation_concept_serialize(
            concept_id=concept_id,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiCalculationConceptDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_analytic_model.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def get_calculation_concept_without_preload_content(
        self,
        concept_id: Annotated[StrictStr, Field(description="The ID of the concept to retrieve the configuration for.")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Retrieve the configuration of a calculation concept

        Retrieve the configuration details of a calculation concept in production.

        :param concept_id: The ID of the concept to retrieve the configuration for. (required)
        :type concept_id: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_calculation_concept_serialize(
            concept_id=concept_id,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiCalculationConceptDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_calculation_concept_serialize(
        self,
        concept_id,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if concept_id is not None:
            _path_params['conceptId'] = concept_id
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/admin/calculation-concepts/{conceptId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_calculation_concepts(
        self,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DesignerApiCalculationConceptListDTO:
        """Retrieve all calculation concepts

        Retrieve the calculation concepts available in production.

        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_calculation_concepts_serialize(
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiCalculationConceptListDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_analytic_model.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def get_calculation_concepts_with_http_info(
        self,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DesignerApiCalculationConceptListDTO]:
        """Retrieve all calculation concepts

        Retrieve the calculation concepts available in production.

        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_calculation_concepts_serialize(
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiCalculationConceptListDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_analytic_model.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def get_calculation_concepts_without_preload_content(
        self,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Retrieve all calculation concepts

        Retrieve the calculation concepts available in production.

        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_calculation_concepts_serialize(
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiCalculationConceptListDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_calculation_concepts_serialize(
        self,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/admin/calculation-concepts',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_selection_concept(
        self,
        concept_id: Annotated[StrictStr, Field(description="The ID of the concept to retrieve the configuration for.")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DesignerApiSelectionConceptDTO:
        """Retrieve the configuration of a selection concept

        Retrieve the configuration details of a selection concept in production.

        :param concept_id: The ID of the concept to retrieve the configuration for. (required)
        :type concept_id: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_selection_concept_serialize(
            concept_id=concept_id,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiSelectionConceptDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_analytic_model.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def get_selection_concept_with_http_info(
        self,
        concept_id: Annotated[StrictStr, Field(description="The ID of the concept to retrieve the configuration for.")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DesignerApiSelectionConceptDTO]:
        """Retrieve the configuration of a selection concept

        Retrieve the configuration details of a selection concept in production.

        :param concept_id: The ID of the concept to retrieve the configuration for. (required)
        :type concept_id: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_selection_concept_serialize(
            concept_id=concept_id,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiSelectionConceptDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_analytic_model.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def get_selection_concept_without_preload_content(
        self,
        concept_id: Annotated[StrictStr, Field(description="The ID of the concept to retrieve the configuration for.")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Retrieve the configuration of a selection concept

        Retrieve the configuration details of a selection concept in production.

        :param concept_id: The ID of the concept to retrieve the configuration for. (required)
        :type concept_id: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_selection_concept_serialize(
            concept_id=concept_id,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiSelectionConceptDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_selection_concept_serialize(
        self,
        concept_id,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if concept_id is not None:
            _path_params['conceptId'] = concept_id
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/admin/selection-concepts/{conceptId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_selection_concepts(
        self,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DesignerApiSelectionConceptListDTO:
        """Retrieve all selection concepts

        Retrieve the selection concepts available in production.

        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_selection_concepts_serialize(
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiSelectionConceptListDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_analytic_model.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def get_selection_concepts_with_http_info(
        self,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DesignerApiSelectionConceptListDTO]:
        """Retrieve all selection concepts

        Retrieve the selection concepts available in production.

        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_selection_concepts_serialize(
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiSelectionConceptListDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_analytic_model.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def get_selection_concepts_without_preload_content(
        self,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Retrieve all selection concepts

        Retrieve the selection concepts available in production.

        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_selection_concepts_serialize(
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiSelectionConceptListDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_selection_concepts_serialize(
        self,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/admin/selection-concepts',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def map_calculation_concept(
        self,
        concept_id: Annotated[StrictStr, Field(description="The UUID of the concept to configure.")],
        designer_api_calculation_concept_configuration_map_dto: DesignerApiCalculationConceptConfigurationMapDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DesignerApiConceptConfigurationResultDTO:
        """Map dimension members to nodes in a calculation concept

        Map dimension members to nodes in a calculation concept.  The changes are applied in a new project and published to production.   The body of this API is the source of truth for dimension members mapped to the concept. For example, if a node in  the body does not have any dimension members, all existing dimension members mapped to that node will be removed.

        :param concept_id: The UUID of the concept to configure. (required)
        :type concept_id: str
        :param designer_api_calculation_concept_configuration_map_dto: (required)
        :type designer_api_calculation_concept_configuration_map_dto: DesignerApiCalculationConceptConfigurationMapDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._map_calculation_concept_serialize(
            concept_id=concept_id,
            designer_api_calculation_concept_configuration_map_dto=designer_api_calculation_concept_configuration_map_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiConceptConfigurationResultDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_analytic_model.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def map_calculation_concept_with_http_info(
        self,
        concept_id: Annotated[StrictStr, Field(description="The UUID of the concept to configure.")],
        designer_api_calculation_concept_configuration_map_dto: DesignerApiCalculationConceptConfigurationMapDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DesignerApiConceptConfigurationResultDTO]:
        """Map dimension members to nodes in a calculation concept

        Map dimension members to nodes in a calculation concept.  The changes are applied in a new project and published to production.   The body of this API is the source of truth for dimension members mapped to the concept. For example, if a node in  the body does not have any dimension members, all existing dimension members mapped to that node will be removed.

        :param concept_id: The UUID of the concept to configure. (required)
        :type concept_id: str
        :param designer_api_calculation_concept_configuration_map_dto: (required)
        :type designer_api_calculation_concept_configuration_map_dto: DesignerApiCalculationConceptConfigurationMapDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._map_calculation_concept_serialize(
            concept_id=concept_id,
            designer_api_calculation_concept_configuration_map_dto=designer_api_calculation_concept_configuration_map_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiConceptConfigurationResultDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_analytic_model.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def map_calculation_concept_without_preload_content(
        self,
        concept_id: Annotated[StrictStr, Field(description="The UUID of the concept to configure.")],
        designer_api_calculation_concept_configuration_map_dto: DesignerApiCalculationConceptConfigurationMapDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Map dimension members to nodes in a calculation concept

        Map dimension members to nodes in a calculation concept.  The changes are applied in a new project and published to production.   The body of this API is the source of truth for dimension members mapped to the concept. For example, if a node in  the body does not have any dimension members, all existing dimension members mapped to that node will be removed.

        :param concept_id: The UUID of the concept to configure. (required)
        :type concept_id: str
        :param designer_api_calculation_concept_configuration_map_dto: (required)
        :type designer_api_calculation_concept_configuration_map_dto: DesignerApiCalculationConceptConfigurationMapDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._map_calculation_concept_serialize(
            concept_id=concept_id,
            designer_api_calculation_concept_configuration_map_dto=designer_api_calculation_concept_configuration_map_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiConceptConfigurationResultDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _map_calculation_concept_serialize(
        self,
        concept_id,
        designer_api_calculation_concept_configuration_map_dto,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if concept_id is not None:
            _path_params['conceptId'] = concept_id
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter
        if designer_api_calculation_concept_configuration_map_dto is not None:
            _body_params = designer_api_calculation_concept_configuration_map_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/v1/admin/calculation-concepts/{conceptId}/configure',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def map_selection_concept(
        self,
        concept_id: Annotated[StrictStr, Field(description="The UUID of the concept to configure.")],
        designer_api_selection_concept_configuration_map_dto: DesignerApiSelectionConceptConfigurationMapDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DesignerApiConceptConfigurationResultDTO:
        """Map dimension members to a selection concept

        Map dimension members to a selection concept.  The changes are applied to a new project and published to production.   The body of this API is the source of truth for dimension members mapped to the concept. For example, if a node in  the body does not have any dimension members, all existing dimension members mapped to that node will be removed.

        :param concept_id: The UUID of the concept to configure. (required)
        :type concept_id: str
        :param designer_api_selection_concept_configuration_map_dto: (required)
        :type designer_api_selection_concept_configuration_map_dto: DesignerApiSelectionConceptConfigurationMapDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._map_selection_concept_serialize(
            concept_id=concept_id,
            designer_api_selection_concept_configuration_map_dto=designer_api_selection_concept_configuration_map_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiConceptConfigurationResultDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_analytic_model.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def map_selection_concept_with_http_info(
        self,
        concept_id: Annotated[StrictStr, Field(description="The UUID of the concept to configure.")],
        designer_api_selection_concept_configuration_map_dto: DesignerApiSelectionConceptConfigurationMapDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DesignerApiConceptConfigurationResultDTO]:
        """Map dimension members to a selection concept

        Map dimension members to a selection concept.  The changes are applied to a new project and published to production.   The body of this API is the source of truth for dimension members mapped to the concept. For example, if a node in  the body does not have any dimension members, all existing dimension members mapped to that node will be removed.

        :param concept_id: The UUID of the concept to configure. (required)
        :type concept_id: str
        :param designer_api_selection_concept_configuration_map_dto: (required)
        :type designer_api_selection_concept_configuration_map_dto: DesignerApiSelectionConceptConfigurationMapDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._map_selection_concept_serialize(
            concept_id=concept_id,
            designer_api_selection_concept_configuration_map_dto=designer_api_selection_concept_configuration_map_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiConceptConfigurationResultDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_analytic_model.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def map_selection_concept_without_preload_content(
        self,
        concept_id: Annotated[StrictStr, Field(description="The UUID of the concept to configure.")],
        designer_api_selection_concept_configuration_map_dto: DesignerApiSelectionConceptConfigurationMapDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Map dimension members to a selection concept

        Map dimension members to a selection concept.  The changes are applied to a new project and published to production.   The body of this API is the source of truth for dimension members mapped to the concept. For example, if a node in  the body does not have any dimension members, all existing dimension members mapped to that node will be removed.

        :param concept_id: The UUID of the concept to configure. (required)
        :type concept_id: str
        :param designer_api_selection_concept_configuration_map_dto: (required)
        :type designer_api_selection_concept_configuration_map_dto: DesignerApiSelectionConceptConfigurationMapDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._map_selection_concept_serialize(
            concept_id=concept_id,
            designer_api_selection_concept_configuration_map_dto=designer_api_selection_concept_configuration_map_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DesignerApiConceptConfigurationResultDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _map_selection_concept_serialize(
        self,
        concept_id,
        designer_api_selection_concept_configuration_map_dto,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if concept_id is not None:
            _path_params['conceptId'] = concept_id
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter
        if designer_api_selection_concept_configuration_map_dto is not None:
            _body_params = designer_api_selection_concept_configuration_map_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/v1/admin/selection-concepts/{conceptId}/configure',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1906
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_basic_information_dto import ServicingV2ObjectconfigurationBasicInformationDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_metric_type_details_dto import ServicingV2ObjectconfigurationMetricTypeDetailsDTO
from typing import Optional, Set
from typing_extensions import Self

class ServicingV2ObjectconfigurationMetricDefinitionDTO(BaseModel):
    """
    Information about the metric, such as its object name, basic information, and additive type.
    """ # noqa: E501
    uuid: Optional[StrictStr] = Field(default=None, description="The UUID identifying the metric.")
    object_name: Optional[StrictStr] = Field(default=None, description="The object name of the metric.", alias="objectName")
    basic_information: Optional[ServicingV2ObjectconfigurationBasicInformationDTO] = Field(default=None, description="Fields that identify and describe the metric, such as its display name, description, and explanation.", alias="basicInformation")
    details: Optional[ServicingV2ObjectconfigurationMetricTypeDetailsDTO] = Field(default=None, description="The metric type and its details.")
    additive_type: Optional[StrictStr] = Field(default=None, description="How to sum the metric's values. Valid values:  - `fullyAdditive`: Sums the metric over any dimension, concept, or time period.  - `balance`: Sums the metric over any dimension or concept, but not time period.  - `nonAdditive`: Metric values are not additive.", alias="additiveType")
    __properties: ClassVar[List[str]] = ["uuid", "objectName", "basicInformation", "details", "additiveType"]

    @field_validator('additive_type')
    def additive_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['fullyAdditive', 'balance', 'nonAdditive', 'unknown']):
            raise ValueError("must be one of enum values ('fullyAdditive', 'balance', 'nonAdditive', 'unknown')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServicingV2ObjectconfigurationMetricDefinitionDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of basic_information
        if self.basic_information:
            _dict['basicInformation'] = self.basic_information.to_dict()
        # override the default output from pydantic by calling `to_dict()` of details
        if self.details:
            _dict['details'] = self.details.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServicingV2ObjectconfigurationMetricDefinitionDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "uuid": obj.get("uuid"),
            "objectName": obj.get("objectName"),
            "basicInformation": ServicingV2ObjectconfigurationBasicInformationDTO.from_dict(obj["basicInformation"]) if obj.get("basicInformation") is not None else None,
            "details": ServicingV2ObjectconfigurationMetricTypeDetailsDTO.from_dict(obj["details"]) if obj.get("details") is not None else None,
            "additiveType": obj.get("additiveType")
        })
        return _obj





# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1906
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_analytic_model.models.servicing_user_group_assignment_dto import ServicingUserGroupAssignmentDTO
from typing import Optional, Set
from typing_extensions import Self

class ServicingVeeQuestionChangeSuccessDTO(BaseModel):
    """
    ServicingVeeQuestionChangeSuccessDTO
    """ # noqa: E501
    question: Optional[StrictStr] = Field(default=None, description="The sample question in plain language that was successfully changed.")
    question_id: Optional[StrictStr] = Field(default=None, description="The unique identifier of the sample question that was successfully changed.", alias="questionId")
    visible_in_vee: Optional[StrictBool] = Field(default=None, description="If `true`, the question is visible in Vee.", alias="visibleInVee")
    category_id: Optional[StrictStr] = Field(default=None, description="The unique identifier of the category of the question that was successfully changed.", alias="categoryId")
    user_group_assignment: Optional[ServicingUserGroupAssignmentDTO] = Field(default=None, description="The user group IDs that were successfully assigned to the sample question.", alias="userGroupAssignment")
    tenant_code: Optional[StrictStr] = Field(default=None, description="The tenant that the sample question was changed in.", alias="tenantCode")
    project_id: Optional[StrictStr] = Field(default=None, description="The project that the sample question was changed in.", alias="projectId")
    __properties: ClassVar[List[str]] = ["question", "questionId", "visibleInVee", "categoryId", "userGroupAssignment", "tenantCode", "projectId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServicingVeeQuestionChangeSuccessDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of user_group_assignment
        if self.user_group_assignment:
            _dict['userGroupAssignment'] = self.user_group_assignment.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServicingVeeQuestionChangeSuccessDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "question": obj.get("question"),
            "questionId": obj.get("questionId"),
            "visibleInVee": obj.get("visibleInVee"),
            "categoryId": obj.get("categoryId"),
            "userGroupAssignment": ServicingUserGroupAssignmentDTO.from_dict(obj["userGroupAssignment"]) if obj.get("userGroupAssignment") is not None else None,
            "tenantCode": obj.get("tenantCode"),
            "projectId": obj.get("projectId")
        })
        return _obj





# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1906
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_analytic_model.models.dataservices_datamodel_aggregation_type_parameter_dto import DataservicesDatamodelAggregationTypeParameterDTO
from visier_api_analytic_model.models.dataservices_datamodel_member_parameter_definition_dto import DataservicesDatamodelMemberParameterDefinitionDTO
from visier_api_analytic_model.models.dataservices_datamodel_numeric_parameter_definition_dto import DataservicesDatamodelNumericParameterDefinitionDTO
from visier_api_analytic_model.models.dataservices_datamodel_plan_parameter_definition_dto import DataservicesDatamodelPlanParameterDefinitionDTO
from typing import Optional, Set
from typing_extensions import Self

class DataservicesDatamodelParameterDefinitionDTO(BaseModel):
    """
    Parameters generalize object definitions so that end users can provide values at query run time.
    """ # noqa: E501
    member_parameter: Optional[DataservicesDatamodelMemberParameterDefinitionDTO] = Field(default=None, description="A filter parameter that can be set with dimension members for the end user to select.", alias="memberParameter")
    numeric_parameter: Optional[DataservicesDatamodelNumericParameterDefinitionDTO] = Field(default=None, description="A parameter with a numeric data type. A numeric parameter can be set with an optional default value and value range.", alias="numericParameter")
    plan_parameter: Optional[DataservicesDatamodelPlanParameterDefinitionDTO] = Field(default=None, description="A parameter on a planning metric. Plan parameters resolve planning model metrics to a specific plan and scenario or snapshot.", alias="planParameter")
    aggregation_type_parameter: Optional[DataservicesDatamodelAggregationTypeParameterDTO] = Field(default=None, description="An aggregation parameter. Such parameters enable control over how applicable metrics aggregate their results.", alias="aggregationTypeParameter")
    __properties: ClassVar[List[str]] = ["memberParameter", "numericParameter", "planParameter", "aggregationTypeParameter"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DataservicesDatamodelParameterDefinitionDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of member_parameter
        if self.member_parameter:
            _dict['memberParameter'] = self.member_parameter.to_dict()
        # override the default output from pydantic by calling `to_dict()` of numeric_parameter
        if self.numeric_parameter:
            _dict['numericParameter'] = self.numeric_parameter.to_dict()
        # override the default output from pydantic by calling `to_dict()` of plan_parameter
        if self.plan_parameter:
            _dict['planParameter'] = self.plan_parameter.to_dict()
        # override the default output from pydantic by calling `to_dict()` of aggregation_type_parameter
        if self.aggregation_type_parameter:
            _dict['aggregationTypeParameter'] = self.aggregation_type_parameter.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DataservicesDatamodelParameterDefinitionDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "memberParameter": DataservicesDatamodelMemberParameterDefinitionDTO.from_dict(obj["memberParameter"]) if obj.get("memberParameter") is not None else None,
            "numericParameter": DataservicesDatamodelNumericParameterDefinitionDTO.from_dict(obj["numericParameter"]) if obj.get("numericParameter") is not None else None,
            "planParameter": DataservicesDatamodelPlanParameterDefinitionDTO.from_dict(obj["planParameter"]) if obj.get("planParameter") is not None else None,
            "aggregationTypeParameter": DataservicesDatamodelAggregationTypeParameterDTO.from_dict(obj["aggregationTypeParameter"]) if obj.get("aggregationTypeParameter") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1906
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_analytic_model.models.dataservices_datamodel_object_reference_dto import DataservicesDatamodelObjectReferenceDTO
from visier_api_analytic_model.models.dataservices_datamodel_population_configuration_dto import DataservicesDatamodelPopulationConfigurationDTO
from typing import Optional, Set
from typing_extensions import Self

class DataservicesDatamodelAnalyticObjectDTO(BaseModel):
    """
    Analytic objects are the various items that users can analyze in Visier. Analytic objects include subjects, events, and overlays.
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="The unique ID of the analytic object.  Note: See `AnalyticObjects` to get the ID.")
    display_name: Optional[StrictStr] = Field(default=None, description="The localized display name of the analytic object.", alias="displayName")
    description: Optional[StrictStr] = Field(default=None, description="The localized description of the analytic object.")
    type: Optional[StrictStr] = Field(default=None, description="The analytic object type: SUBJECT, EVENT, or OVERLAY.")
    data_start_date: Optional[StrictStr] = Field(default=None, description="The date from which data becomes available for this analytic object.  Note: Format is the number of milliseconds since midnight 01 January, 1970 UTC as a string.  Epochs are expressed as 64-bit integers and represented as stringified longs in JSON due to JSON's inherent  limitation in representing large numbers.", alias="dataStartDate")
    data_end_date: Optional[StrictStr] = Field(default=None, description="The date from which data is no longer available for this analytic object.  Note: Format is the number of milliseconds since midnight 01 January, 1970 UTC as a string.  Epochs are expressed as 64-bit integers and represented as stringified longs in JSON due to JSON's inherent  limitation in representing large numbers.", alias="dataEndDate")
    property_ids: Optional[List[StrictStr]] = Field(default=None, description="A list of strings representing IDs of the properties that belong to this analytic object.", alias="propertyIds")
    dimension_ids: Optional[List[StrictStr]] = Field(default=None, description="A list of strings representing IDs of the dimensions that belong to this analytic object.", alias="dimensionIds")
    selection_concept_ids: Optional[List[StrictStr]] = Field(default=None, description="A list of strings representing IDs of the selection concepts that belong to this analytic object.  Note: If there are no selection concepts, this field is omitted.", alias="selectionConceptIds")
    object_references: Optional[List[DataservicesDatamodelObjectReferenceDTO]] = Field(default=None, description="A list of references from this analytic object to other analytic objects.  Note: If there are no references, this field is omitted.", alias="objectReferences")
    population_configuration: Optional[DataservicesDatamodelPopulationConfigurationDTO] = Field(default=None, description="A set of property and dimension references configured by Visier or an administrator to tell the platform what  properties and dimensions to use when doing population insight calculations. These are the distinguishing  properties, change history properties, and grouping dimensions to use in AI insights. This field is optional and  is only available for subjects.", alias="populationConfiguration")
    __properties: ClassVar[List[str]] = ["id", "displayName", "description", "type", "dataStartDate", "dataEndDate", "propertyIds", "dimensionIds", "selectionConceptIds", "objectReferences", "populationConfiguration"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['SUBJECT', 'EVENT', 'OVERLAY']):
            raise ValueError("must be one of enum values ('SUBJECT', 'EVENT', 'OVERLAY')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DataservicesDatamodelAnalyticObjectDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in object_references (list)
        _items = []
        if self.object_references:
            for _item_object_references in self.object_references:
                if _item_object_references:
                    _items.append(_item_object_references.to_dict())
            _dict['objectReferences'] = _items
        # override the default output from pydantic by calling `to_dict()` of population_configuration
        if self.population_configuration:
            _dict['populationConfiguration'] = self.population_configuration.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DataservicesDatamodelAnalyticObjectDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "displayName": obj.get("displayName"),
            "description": obj.get("description"),
            "type": obj.get("type"),
            "dataStartDate": obj.get("dataStartDate"),
            "dataEndDate": obj.get("dataEndDate"),
            "propertyIds": obj.get("propertyIds"),
            "dimensionIds": obj.get("dimensionIds"),
            "selectionConceptIds": obj.get("selectionConceptIds"),
            "objectReferences": [DataservicesDatamodelObjectReferenceDTO.from_dict(_item) for _item in obj["objectReferences"]] if obj.get("objectReferences") is not None else None,
            "populationConfiguration": DataservicesDatamodelPopulationConfigurationDTO.from_dict(obj["populationConfiguration"]) if obj.get("populationConfiguration") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1906
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_analytic_model.models.dataservices_datamodel_dimension_reference_dto import DataservicesDatamodelDimensionReferenceDTO
from visier_api_analytic_model.models.dataservices_datamodel_property_reference_dto import DataservicesDatamodelPropertyReferenceDTO
from typing import Optional, Set
from typing_extensions import Self

class DataservicesDatamodelPopulationConfigurationDTO(BaseModel):
    """
    A set of property and dimension references configured by Visier or an administrator to tell the platform what  properties and dimensions to use when doing population insight calculations. These are the distinguishing properties,  change history properties, and grouping dimensions to use in AI insights.
    """ # noqa: E501
    distinguishing_properties: Optional[List[DataservicesDatamodelPropertyReferenceDTO]] = Field(default=None, description="Properties that are used by default to compare subject members.", alias="distinguishingProperties")
    change_history_properties: Optional[List[DataservicesDatamodelPropertyReferenceDTO]] = Field(default=None, description="Properties that are used by default to compare subject members over time.", alias="changeHistoryProperties")
    grouping_dimensions: Optional[List[DataservicesDatamodelDimensionReferenceDTO]] = Field(default=None, description="Dimensions to use for grouping and clustering the population.", alias="groupingDimensions")
    __properties: ClassVar[List[str]] = ["distinguishingProperties", "changeHistoryProperties", "groupingDimensions"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DataservicesDatamodelPopulationConfigurationDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in distinguishing_properties (list)
        _items = []
        if self.distinguishing_properties:
            for _item_distinguishing_properties in self.distinguishing_properties:
                if _item_distinguishing_properties:
                    _items.append(_item_distinguishing_properties.to_dict())
            _dict['distinguishingProperties'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in change_history_properties (list)
        _items = []
        if self.change_history_properties:
            for _item_change_history_properties in self.change_history_properties:
                if _item_change_history_properties:
                    _items.append(_item_change_history_properties.to_dict())
            _dict['changeHistoryProperties'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in grouping_dimensions (list)
        _items = []
        if self.grouping_dimensions:
            for _item_grouping_dimensions in self.grouping_dimensions:
                if _item_grouping_dimensions:
                    _items.append(_item_grouping_dimensions.to_dict())
            _dict['groupingDimensions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DataservicesDatamodelPopulationConfigurationDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "distinguishingProperties": [DataservicesDatamodelPropertyReferenceDTO.from_dict(_item) for _item in obj["distinguishingProperties"]] if obj.get("distinguishingProperties") is not None else None,
            "changeHistoryProperties": [DataservicesDatamodelPropertyReferenceDTO.from_dict(_item) for _item in obj["changeHistoryProperties"]] if obj.get("changeHistoryProperties") is not None else None,
            "groupingDimensions": [DataservicesDatamodelDimensionReferenceDTO.from_dict(_item) for _item in obj["groupingDimensions"]] if obj.get("groupingDimensions") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1906
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

import visier_api_analytic_model.models
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_failed_change_dto import ServicingV2ObjectconfigurationFailedChangeDTO

class TestServicingV2ObjectconfigurationFailedChangeDTO(unittest.TestCase):
    """ServicingV2ObjectconfigurationFailedChangeDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServicingV2ObjectconfigurationFailedChangeDTO:
        """Test ServicingV2ObjectconfigurationFailedChangeDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """

        if include_optional:
            return ServicingV2ObjectconfigurationFailedChangeDTO(
                execution_context = visier_api_analytic_model.models.servicing/v2/objectconfiguration/execution_context_dto.servicing.v2.objectconfiguration.ExecutionContextDTO(
                    tenant_code = '', 
                    project_id = '', ),
                object_name = '',
                uuid = '',
                display_name = '',
                messages = [
                    ''
                    ]
            )
        else:
            return ServicingV2ObjectconfigurationFailedChangeDTO(
        )

    def testServicingV2ObjectconfigurationFailedChangeDTO(self):
        """Test ServicingV2ObjectconfigurationFailedChangeDTO"""
        def validate_instance(instance):
            ServicingV2ObjectconfigurationFailedChangeDTO.model_validate(inst_req_only)
            instance_deserialized = ServicingV2ObjectconfigurationFailedChangeDTO.from_dict(instance.to_dict())
            assert instance == instance_deserialized

        inst_req_only = self.make_instance(include_optional=False)
        validate_instance(inst_req_only)

        inst_req_and_optional = self.make_instance(include_optional=True)
        validate_instance(inst_req_and_optional)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1906
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_analytic_model.models.planning_plan_item_dto import PlanningPlanItemDTO
from visier_api_analytic_model.models.planning_plan_segment_level_dto import PlanningPlanSegmentLevelDTO
from visier_api_analytic_model.models.planning_plan_segment_level_member_list_dto import PlanningPlanSegmentLevelMemberListDTO
from visier_api_analytic_model.models.planning_plan_time_period_dto import PlanningPlanTimePeriodDTO
from typing import Optional, Set
from typing_extensions import Self

class PlanningPlanSchemaDTO(BaseModel):
    """
    Information about a plan's schema.
    """ # noqa: E501
    plan_items: Optional[List[PlanningPlanItemDTO]] = Field(default=None, description="A collection of editable plan items in a plan.", alias="planItems")
    time_periods: Optional[List[PlanningPlanTimePeriodDTO]] = Field(default=None, description="The editable time periods in a plan. These time periods are the columns in the planning grid.", alias="timePeriods")
    plan_segment_levels: Optional[List[PlanningPlanSegmentLevelDTO]] = Field(default=None, description="The dimensions that the plan is segmented by.", alias="planSegmentLevels")
    plan_segment_level_members: Optional[List[PlanningPlanSegmentLevelMemberListDTO]] = Field(default=None, description="A collection of members grouped by their dimension and level.  The combination of these member IDs points to a specific row in the plan.", alias="planSegmentLevelMembers")
    __properties: ClassVar[List[str]] = ["planItems", "timePeriods", "planSegmentLevels", "planSegmentLevelMembers"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PlanningPlanSchemaDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in plan_items (list)
        _items = []
        if self.plan_items:
            for _item_plan_items in self.plan_items:
                if _item_plan_items:
                    _items.append(_item_plan_items.to_dict())
            _dict['planItems'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in time_periods (list)
        _items = []
        if self.time_periods:
            for _item_time_periods in self.time_periods:
                if _item_time_periods:
                    _items.append(_item_time_periods.to_dict())
            _dict['timePeriods'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in plan_segment_levels (list)
        _items = []
        if self.plan_segment_levels:
            for _item_plan_segment_levels in self.plan_segment_levels:
                if _item_plan_segment_levels:
                    _items.append(_item_plan_segment_levels.to_dict())
            _dict['planSegmentLevels'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in plan_segment_level_members (list)
        _items = []
        if self.plan_segment_level_members:
            for _item_plan_segment_level_members in self.plan_segment_level_members:
                if _item_plan_segment_level_members:
                    _items.append(_item_plan_segment_level_members.to_dict())
            _dict['planSegmentLevelMembers'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PlanningPlanSchemaDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "planItems": [PlanningPlanItemDTO.from_dict(_item) for _item in obj["planItems"]] if obj.get("planItems") is not None else None,
            "timePeriods": [PlanningPlanTimePeriodDTO.from_dict(_item) for _item in obj["timePeriods"]] if obj.get("timePeriods") is not None else None,
            "planSegmentLevels": [PlanningPlanSegmentLevelDTO.from_dict(_item) for _item in obj["planSegmentLevels"]] if obj.get("planSegmentLevels") is not None else None,
            "planSegmentLevelMembers": [PlanningPlanSegmentLevelMemberListDTO.from_dict(_item) for _item in obj["planSegmentLevelMembers"]] if obj.get("planSegmentLevelMembers") is not None else None
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1906
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


# import models into model package
from visier_api_analytic_model.models.dataservices_common_dimension_member_reference_dto import DataservicesCommonDimensionMemberReferenceDTO
from visier_api_analytic_model.models.dataservices_common_member_values_dto import DataservicesCommonMemberValuesDTO
from visier_api_analytic_model.models.dataservices_datamodel_aggregation_type_option_dto import DataservicesDatamodelAggregationTypeOptionDTO
from visier_api_analytic_model.models.dataservices_datamodel_aggregation_type_parameter_dto import DataservicesDatamodelAggregationTypeParameterDTO
from visier_api_analytic_model.models.dataservices_datamodel_analytic_object_dto import DataservicesDatamodelAnalyticObjectDTO
from visier_api_analytic_model.models.dataservices_datamodel_analytic_objects_dto import DataservicesDatamodelAnalyticObjectsDTO
from visier_api_analytic_model.models.dataservices_datamodel_currencies_dto import DataservicesDatamodelCurrenciesDTO
from visier_api_analytic_model.models.dataservices_datamodel_currency_dto import DataservicesDatamodelCurrencyDTO
from visier_api_analytic_model.models.dataservices_datamodel_currency_rate_dto import DataservicesDatamodelCurrencyRateDTO
from visier_api_analytic_model.models.dataservices_datamodel_currency_rates_dto import DataservicesDatamodelCurrencyRatesDTO
from visier_api_analytic_model.models.dataservices_datamodel_dimension_dto import DataservicesDatamodelDimensionDTO
from visier_api_analytic_model.models.dataservices_datamodel_dimension_mapping_validation_dto import DataservicesDatamodelDimensionMappingValidationDTO
from visier_api_analytic_model.models.dataservices_datamodel_dimension_mapping_validation_execution_dto import DataservicesDatamodelDimensionMappingValidationExecutionDTO
from visier_api_analytic_model.models.dataservices_datamodel_dimension_reference_dto import DataservicesDatamodelDimensionReferenceDTO
from visier_api_analytic_model.models.dataservices_datamodel_dimensions_dto import DataservicesDatamodelDimensionsDTO
from visier_api_analytic_model.models.dataservices_datamodel_level_dto import DataservicesDatamodelLevelDTO
from visier_api_analytic_model.models.dataservices_datamodel_member_dto import DataservicesDatamodelMemberDTO
from visier_api_analytic_model.models.dataservices_datamodel_member_parameter_definition_dto import DataservicesDatamodelMemberParameterDefinitionDTO
from visier_api_analytic_model.models.dataservices_datamodel_members_dto import DataservicesDatamodelMembersDTO
from visier_api_analytic_model.models.dataservices_datamodel_metric_dto import DataservicesDatamodelMetricDTO
from visier_api_analytic_model.models.dataservices_datamodel_metrics_dto import DataservicesDatamodelMetricsDTO
from visier_api_analytic_model.models.dataservices_datamodel_numeric_parameter_definition_dto import DataservicesDatamodelNumericParameterDefinitionDTO
from visier_api_analytic_model.models.dataservices_datamodel_object_reference_dto import DataservicesDatamodelObjectReferenceDTO
from visier_api_analytic_model.models.dataservices_datamodel_parameter_definition_dto import DataservicesDatamodelParameterDefinitionDTO
from visier_api_analytic_model.models.dataservices_datamodel_plan_parameter_definition_dto import DataservicesDatamodelPlanParameterDefinitionDTO
from visier_api_analytic_model.models.dataservices_datamodel_planning_concept_filter_context_dto import DataservicesDatamodelPlanningConceptFilterContextDTO
from visier_api_analytic_model.models.dataservices_datamodel_planning_hierarchy_filter_context_dto import DataservicesDatamodelPlanningHierarchyFilterContextDTO
from visier_api_analytic_model.models.dataservices_datamodel_planning_model_dto import DataservicesDatamodelPlanningModelDTO
from visier_api_analytic_model.models.dataservices_datamodel_planning_models_dto import DataservicesDatamodelPlanningModelsDTO
from visier_api_analytic_model.models.dataservices_datamodel_planning_plan_context_dto import DataservicesDatamodelPlanningPlanContextDTO
from visier_api_analytic_model.models.dataservices_datamodel_planning_plan_dto import DataservicesDatamodelPlanningPlanDTO
from visier_api_analytic_model.models.dataservices_datamodel_planning_plans_dto import DataservicesDatamodelPlanningPlansDTO
from visier_api_analytic_model.models.dataservices_datamodel_population_configuration_dto import DataservicesDatamodelPopulationConfigurationDTO
from visier_api_analytic_model.models.dataservices_datamodel_prediction_dto import DataservicesDatamodelPredictionDTO
from visier_api_analytic_model.models.dataservices_datamodel_predictions_dto import DataservicesDatamodelPredictionsDTO
from visier_api_analytic_model.models.dataservices_datamodel_properties_dto import DataservicesDatamodelPropertiesDTO
from visier_api_analytic_model.models.dataservices_datamodel_property_dto import DataservicesDatamodelPropertyDTO
from visier_api_analytic_model.models.dataservices_datamodel_property_reference_dto import DataservicesDatamodelPropertyReferenceDTO
from visier_api_analytic_model.models.dataservices_datamodel_scenario_or_snapshot_dto import DataservicesDatamodelScenarioOrSnapshotDTO
from visier_api_analytic_model.models.dataservices_datamodel_selection_concept_dto import DataservicesDatamodelSelectionConceptDTO
from visier_api_analytic_model.models.dataservices_datamodel_selection_concepts_dto import DataservicesDatamodelSelectionConceptsDTO
from visier_api_analytic_model.models.dataservices_datamodel_tag_map_element_dto import DataservicesDatamodelTagMapElementDTO
from visier_api_analytic_model.models.dataservices_datamodel_validity_range_dto import DataservicesDatamodelValidityRangeDTO
from visier_api_analytic_model.models.designer_api_analytic_object_filter_dto import DesignerApiAnalyticObjectFilterDTO
from visier_api_analytic_model.models.designer_api_calculation_concept_configuration_dto import DesignerApiCalculationConceptConfigurationDTO
from visier_api_analytic_model.models.designer_api_calculation_concept_configuration_map_dto import DesignerApiCalculationConceptConfigurationMapDTO
from visier_api_analytic_model.models.designer_api_calculation_concept_dto import DesignerApiCalculationConceptDTO
from visier_api_analytic_model.models.designer_api_calculation_concept_list_dto import DesignerApiCalculationConceptListDTO
from visier_api_analytic_model.models.designer_api_concept_configuration_result_dto import DesignerApiConceptConfigurationResultDTO
from visier_api_analytic_model.models.designer_api_dimension_filter_dto import DesignerApiDimensionFilterDTO
from visier_api_analytic_model.models.designer_api_dimension_member_dto import DesignerApiDimensionMemberDTO
from visier_api_analytic_model.models.designer_api_perspective_configuration_dto import DesignerApiPerspectiveConfigurationDTO
from visier_api_analytic_model.models.designer_api_perspective_node_dto import DesignerApiPerspectiveNodeDTO
from visier_api_analytic_model.models.designer_api_selection_concept_configuration_dto import DesignerApiSelectionConceptConfigurationDTO
from visier_api_analytic_model.models.designer_api_selection_concept_configuration_map_dto import DesignerApiSelectionConceptConfigurationMapDTO
from visier_api_analytic_model.models.designer_api_selection_concept_dto import DesignerApiSelectionConceptDTO
from visier_api_analytic_model.models.designer_api_selection_concept_list_dto import DesignerApiSelectionConceptListDTO
from visier_api_analytic_model.models.planning_get_plan_list_response_dto import PlanningGetPlanListResponseDTO
from visier_api_analytic_model.models.planning_plan_data_load_error_dto import PlanningPlanDataLoadErrorDTO
from visier_api_analytic_model.models.planning_plan_info_dto import PlanningPlanInfoDTO
from visier_api_analytic_model.models.planning_plan_item_dto import PlanningPlanItemDTO
from visier_api_analytic_model.models.planning_plan_schema_dto import PlanningPlanSchemaDTO
from visier_api_analytic_model.models.planning_plan_segment_level_dto import PlanningPlanSegmentLevelDTO
from visier_api_analytic_model.models.planning_plan_segment_level_member_dto import PlanningPlanSegmentLevelMemberDTO
from visier_api_analytic_model.models.planning_plan_segment_level_member_list_dto import PlanningPlanSegmentLevelMemberListDTO
from visier_api_analytic_model.models.planning_plan_time_period_dto import PlanningPlanTimePeriodDTO
from visier_api_analytic_model.models.planning_plan_with_schema_dto import PlanningPlanWithSchemaDTO
from visier_api_analytic_model.models.planning_scenario_info_dto import PlanningScenarioInfoDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_calculated_property_type_dto import ServicingObjectconfigurationCalculatedPropertyTypeDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_dependent_dto import ServicingObjectconfigurationDependentDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_dimension_change_definition_dto import ServicingObjectconfigurationDimensionChangeDefinitionDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_dimension_change_definitions_by_tenant_dto import ServicingObjectconfigurationDimensionChangeDefinitionsByTenantDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_dimensions_change_definitions_dto import ServicingObjectconfigurationDimensionsChangeDefinitionsDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_object_change_failure_dto import ServicingObjectconfigurationObjectChangeFailureDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_object_change_success_dto import ServicingObjectconfigurationObjectChangeSuccessDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_objects_bulk_change_response_dto import ServicingObjectconfigurationObjectsBulkChangeResponseDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_properties_change_definitions_dto import ServicingObjectconfigurationPropertiesChangeDefinitionsDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_properties_delete_definitions_dto import ServicingObjectconfigurationPropertiesDeleteDefinitionsDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_property_bulk_delete_response_dto import ServicingObjectconfigurationPropertyBulkDeleteResponseDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_property_change_definition_dto import ServicingObjectconfigurationPropertyChangeDefinitionDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_property_change_definitions_by_tenant_dto import ServicingObjectconfigurationPropertyChangeDefinitionsByTenantDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_property_delete_definitions_by_tenant_dto import ServicingObjectconfigurationPropertyDeleteDefinitionsByTenantDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_property_delete_failure_dto import ServicingObjectconfigurationPropertyDeleteFailureDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_property_delete_success_dto import ServicingObjectconfigurationPropertyDeleteSuccessDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_property_type_dto import ServicingObjectconfigurationPropertyTypeDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_simple_property_type_dto import ServicingObjectconfigurationSimplePropertyTypeDTO
from visier_api_analytic_model.models.servicing_objectconfiguration_tags_dto import ServicingObjectconfigurationTagsDTO
from visier_api_analytic_model.models.servicing_question_categories_api_response_dto import ServicingQuestionCategoriesAPIResponseDTO
from visier_api_analytic_model.models.servicing_question_category_api_response_dto import ServicingQuestionCategoryAPIResponseDTO
from visier_api_analytic_model.models.servicing_sample_question_api_response_dto import ServicingSampleQuestionAPIResponseDTO
from visier_api_analytic_model.models.servicing_sample_questions_api_response_dto import ServicingSampleQuestionsAPIResponseDTO
from visier_api_analytic_model.models.servicing_user_group_assignment_dto import ServicingUserGroupAssignmentDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_analytic_object_definition_dto import ServicingV2ObjectconfigurationAnalyticObjectDefinitionDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_analytic_object_request_dto import ServicingV2ObjectconfigurationAnalyticObjectRequestDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_analytic_object_with_context_dto import ServicingV2ObjectconfigurationAnalyticObjectWithContextDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_basic_information_dto import ServicingV2ObjectconfigurationBasicInformationDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_bulk_change_response_dto import ServicingV2ObjectconfigurationBulkChangeResponseDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_calculated_property_type_dto import ServicingV2ObjectconfigurationCalculatedPropertyTypeDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_concept_definition_dto import ServicingV2ObjectconfigurationConceptDefinitionDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_concept_delete_request_dto import ServicingV2ObjectconfigurationConceptDeleteRequestDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_concept_delete_with_context_dto import ServicingV2ObjectconfigurationConceptDeleteWithContextDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_concept_request_dto import ServicingV2ObjectconfigurationConceptRequestDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_concept_response_dto import ServicingV2ObjectconfigurationConceptResponseDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_concept_type_details_dto import ServicingV2ObjectconfigurationConceptTypeDetailsDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_concept_with_context_dto import ServicingV2ObjectconfigurationConceptWithContextDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_execution_context_dto import ServicingV2ObjectconfigurationExecutionContextDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_failed_change_dto import ServicingV2ObjectconfigurationFailedChangeDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_metric_definition_dto import ServicingV2ObjectconfigurationMetricDefinitionDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_metric_type_details_dto import ServicingV2ObjectconfigurationMetricTypeDetailsDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_object_id_dto import ServicingV2ObjectconfigurationObjectIdDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_process_concept_definition_dto import ServicingV2ObjectconfigurationProcessConceptDefinitionDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_process_concept_member_dto import ServicingV2ObjectconfigurationProcessConceptMemberDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_process_concept_member_list_dto import ServicingV2ObjectconfigurationProcessConceptMemberListDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_process_concept_metric_definition_dto import ServicingV2ObjectconfigurationProcessConceptMetricDefinitionDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_process_concept_metric_list_dto import ServicingV2ObjectconfigurationProcessConceptMetricListDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_process_concept_outcome_dto import ServicingV2ObjectconfigurationProcessConceptOutcomeDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_process_concept_outcome_list_dto import ServicingV2ObjectconfigurationProcessConceptOutcomeListDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_process_concept_property_list_dto import ServicingV2ObjectconfigurationProcessConceptPropertyListDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_process_concept_property_type_dto import ServicingV2ObjectconfigurationProcessConceptPropertyTypeDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_process_concept_stage_dto import ServicingV2ObjectconfigurationProcessConceptStageDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_process_concept_stage_list_dto import ServicingV2ObjectconfigurationProcessConceptStageListDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_property_definition_dto import ServicingV2ObjectconfigurationPropertyDefinitionDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_property_type_details_dto import ServicingV2ObjectconfigurationPropertyTypeDetailsDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_simple_property_type_dto import ServicingV2ObjectconfigurationSimplePropertyTypeDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_successful_change_dto import ServicingV2ObjectconfigurationSuccessfulChangeDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_synonym_list_dto import ServicingV2ObjectconfigurationSynonymListDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_tag_reference_dto import ServicingV2ObjectconfigurationTagReferenceDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_tag_reference_list_dto import ServicingV2ObjectconfigurationTagReferenceListDTO
from visier_api_analytic_model.models.servicing_vee_question_change_definition_dto import ServicingVeeQuestionChangeDefinitionDTO
from visier_api_analytic_model.models.servicing_vee_question_change_definitions_by_tenant_dto import ServicingVeeQuestionChangeDefinitionsByTenantDTO
from visier_api_analytic_model.models.servicing_vee_question_change_failure_dto import ServicingVeeQuestionChangeFailureDTO
from visier_api_analytic_model.models.servicing_vee_question_change_success_dto import ServicingVeeQuestionChangeSuccessDTO
from visier_api_analytic_model.models.servicing_vee_question_delete_definitions_by_tenant_dto import ServicingVeeQuestionDeleteDefinitionsByTenantDTO
from visier_api_analytic_model.models.servicing_vee_questions_bulk_change_response_dto import ServicingVeeQuestionsBulkChangeResponseDTO
from visier_api_analytic_model.models.servicing_vee_questions_change_definitions_dto import ServicingVeeQuestionsChangeDefinitionsDTO
from visier_api_analytic_model.models.servicing_vee_questions_delete_definitions_dto import ServicingVeeQuestionsDeleteDefinitionsDTO
from visier_api_analytic_model.models.status import Status



# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1906
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_basic_information_dto import ServicingV2ObjectconfigurationBasicInformationDTO
from visier_api_analytic_model.models.servicing_v2_objectconfiguration_process_concept_member_list_dto import ServicingV2ObjectconfigurationProcessConceptMemberListDTO
from typing import Optional, Set
from typing_extensions import Self

class ServicingV2ObjectconfigurationProcessConceptStageDTO(BaseModel):
    """
    Information about a process concept stage.
    """ # noqa: E501
    uuid: Optional[StrictStr] = Field(default=None, description="The UUID identifying the process concept stage.")
    object_name: Optional[StrictStr] = Field(default=None, description="The object name of the process concept stage.", alias="objectName")
    basic_information: Optional[ServicingV2ObjectconfigurationBasicInformationDTO] = Field(default=None, description="Fields that identify and describe the concept stage, such as its display name, description, and explanation.", alias="basicInformation")
    mapped_member_list: Optional[ServicingV2ObjectconfigurationProcessConceptMemberListDTO] = Field(default=None, description="The members mapped to the process concept stage.", alias="mappedMemberList")
    __properties: ClassVar[List[str]] = ["uuid", "objectName", "basicInformation", "mappedMemberList"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServicingV2ObjectconfigurationProcessConceptStageDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of basic_information
        if self.basic_information:
            _dict['basicInformation'] = self.basic_information.to_dict()
        # override the default output from pydantic by calling `to_dict()` of mapped_member_list
        if self.mapped_member_list:
            _dict['mappedMemberList'] = self.mapped_member_list.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServicingV2ObjectconfigurationProcessConceptStageDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "uuid": obj.get("uuid"),
            "objectName": obj.get("objectName"),
            "basicInformation": ServicingV2ObjectconfigurationBasicInformationDTO.from_dict(obj["basicInformation"]) if obj.get("basicInformation") is not None else None,
            "mappedMemberList": ServicingV2ObjectconfigurationProcessConceptMemberListDTO.from_dict(obj["mappedMemberList"]) if obj.get("mappedMemberList") is not None else None
        })
        return _obj


